@@ -1572,6 +1572,8 @@ class Compiler:
         type_check: Optional[str] = None,
         source_maps: Optional[str] = None,
         compression: Optional[str] = None,
+        platform: Optional[str] = None,
+        externals: Optional[Sequence[str]] = None,
     ) -> str:
         kwargs = {
             "project_root": project_root,
@@ -1580,6 +1582,8 @@ class Compiler:
             "type_check": type_check,
             "source_maps": source_maps,
             "compression": compression,
+            "platform": platform,
+            "externals": externals,
         }
         _filter_missing_kwargs(kwargs)
         return self._impl.build(entrypoint, **kwargs)
@@ -1594,6 +1598,8 @@ class Compiler:
         type_check: Optional[str] = None,
         source_maps: Optional[str] = None,
         compression: Optional[str] = None,
+        platform: Optional[str] = None,
+        externals: Optional[Sequence[str]] = None,
     ) -> None:
         kwargs = {
             "project_root": project_root,
@@ -1602,6 +1608,8 @@ class Compiler:
             "type_check": type_check,
             "source_maps": source_maps,
             "compression": compression,
+            "platform": platform,
+            "externals": externals,
         }
         _filter_missing_kwargs(kwargs)
         return self._impl.watch(entrypoint, **kwargs)
@@ -1649,16 +1657,11 @@ PackageManagerInstallProgressCallback = Callable[
             "initializing",
             "preparing-dependencies",
             "resolving-package",
-            "using-lockfile-data",
-            "metadata-fetched",
             "fetching-resource",
             "package-already-installed",
             "downloading-package",
             "package-installed",
             "resolving-and-installing-all",
-            "awaiting-completion",
-            "dependencies-processed",
-            "finalizing-manifests",
             "complete",
         ],
         float,
@@ -1667,6 +1670,8 @@ PackageManagerInstallProgressCallback = Callable[
     None,
 ]
 
+PackageRole = Literal["runtime", "development", "optional", "peer"]
+
 
 class PackageManager:
     def __init__(self) -> None:
@@ -1675,6 +1680,14 @@ class PackageManager:
     def __repr__(self) -> str:
         return repr(self._impl)
 
+    @property
+    def registry(self):
+        return self._impl.registry
+
+    @registry.setter
+    def registry(self, value):
+        self._impl.registry = value
+
     @cancellable
     def search(
         self,
@@ -1693,11 +1706,15 @@ class PackageManager:
     def install(
         self,
         project_root: Optional[str] = None,
+        role: Optional[PackageRole] = None,
         specs: Optional[Sequence[str]] = None,
+        omits: Optional[Sequence[PackageRole]] = None,
     ) -> _frida.PackageInstallResult:
         kwargs: Dict[str, Any] = {
             "project_root": project_root,
+            "role": role,
             "specs": specs,
+            "omits": omits,
         }
         _filter_missing_kwargs(kwargs)
         return self._impl.install(**kwargs)
